#!/bin/bash

## Matthew Siegfried, mrsiegfried@ucsd.edu
## 11 November 2015
## Pulls MCMD GPS data for QC purposes

## Not my best work.
## To do: error checking, only will pull for up to 24 hours.

campaign='AN03'
ipadd=157.132.122.54
basedir='http://157.132.122.54/download/Internal/'
ftpuser=anonymous

echo -n '[?] Flight number: '
read answer
flight=$(printf 'flight-%03d' $answer)
flt=$answer

outdir=""$campaign"_F10"$flt
echo '[I] Setting up directories.'
if ! [ -d $outdir ]
then
	echo "[I] Making directory $outdir"
	mkdir $outdir
  mkdir $outdir"/T01"
fi

# GET START DATE
datestr=`date -v -25H +"%Y-%m-%d"`
echo 'START Date (UTC): ' $datestr
read -r -p "[?] Is this the correct START date? [Y/n]" answer
case $answer in
    [nN])
				echo -n '[?] Year [YYYY]:'
				read yyyy_takeoff
				echo -n '[?] Month [MM]:'
				read mm_takeoff
				echo -n '[?] Day [DD]:'
				read dd_takeoff
				datestr=$yyyy_takeoff'-'$mm_takeoff'-'$dd_takeoff
				;;
    *)
        ;;
esac
yyyy_takeoff=${datestr:0:4}
mm_takeoff=${datestr:5:2}
dd_takeoff=${datestr:8:2}
read -p "Acquisition start hour on $yyyy_takeoff $mm_takeoff $dd_takeoff (UTC, 24hr time, 0-23): " hr_takeoff
hr_in=`printf "%02d" $hr_takeoff`00

# GET END DATE
dateland=`date -v -13H +"%Y-%m-%d"`
echo 'END Date (UTC): ' $dateland
read -r -p "[?] Is this the correct END date? [Y/n]" answer
case $answer in
    [nN])
				echo -n '[?] Year [YYYY]:'
				read yyyy_land
				echo -n '[?] Month [MM]:'
				read mm_land
				echo -n '[?] Day [DD]:'
				read dd_land
				dateland=$yyyy_land'-'$mm_land'-'$dd_land
				;;
    *)
        ;;
esac
read -p "Acquisition end hour on $yyyy_land $mm_land $dd_land (UTC, 24hr time, 0-23): " hr_land
hrend=`expr $hr_land + 1`
hr_out=`printf "%02d" $hrend`00
if [[ $hr_out = 2400 ]]; then
  hr_out=0000
fi

outdir=""$campaign"_F10"$flt"_"$yyyy_takeoff""$mm_takeoff""$dd_takeoff
echo '[I] Setting up directories.'
if ! [ -d $outdir ]
then
	echo "[I] Making directory $outdir"
	mkdir $outdir
  mkdir $outdir"/T01"
fi

### pull data ###
done=false
thisYYYY=$yyyy_takeoff
thisMM=$mm_takeoff
thisDD=$dd_takeoff
thisHHHH=$hr_in
ptype='RNX&Ver=2.11'
etype='RNX-GPS&Ver=2.11'

while $notdone
do
    filename=MCMD"$thisYYYY""$thisMM""$thisDD""$thisHHHH"C.T01
    echo "grabbing $filename"

    # wget http://157.132.122.54/download/Internal/
    # 201611/14/1hr10hz/MCMD201611140000C.T01
    wget $basedir"/"$thisYYYY""$thisMM"/"$thisDD"/1hr10hz/"$filename

    #update the date
    newHHHH=`expr $thisHHHH + 100`
    if [[ $newHHHH = 2400 ]]; then
        thisHHHH=`printf "%04d" 0`
        tmpdd=`expr $thisDD + 1`
        thisDD=`printf "%02d" $tmpdd`
    else
        thisHHHH=`printf "%04d" $newHHHH`
    fi
    if [[ $thisHHHH = $hr_out ]]; then
        notdone=false
    fi
done

echo " "
echo "data pulled from MCMD for: "
echo ""$yyyy_takeoff""$mm_takeoff""$dd_takeoff" "$hr_in" UTC" to ""$yyyy_land""$mm_land""$dd_land" "$hr_out" UTC"

### TRIMBLE TO RINEX ###
echo " "
echo "converting from trimble to rinex"
for d in *.T0*
do
  echo "converting $d to .dat"
  ./runpkr00 -d $d
done
echo "converting dat files to rinex (this can take a bit)"
YY=${thisYYYY:2:2}
stem=mcmd`printf "%03d" $flt`

### TRIMBLE TO RINEX ###
./teqc -tr d +C2 +nav "$stem"."$YY"n *.dat > "$stem"."$YY"o
echo "converting dat files to nav (this can take a bit)"

mv -v *o $outdir
mv -v *n $outdir
mv -v *T01 $outdir"/T01"
echo "cleaning up"
rm -v *.dat
