function [Line]  = RosettaFlightToLine(filename,lineFile,dateField,timeField,deploymentNum)
% Returns flight names ('F10XX') for given line number for Rosetta, can
% take cell array as Line input. deploymentNum = 1, if not specified
persistent FlightNum LineNum LineTime deploymentNumber

if ~exist('dateField','var') || isempty(dateField)
    dateField = 3;
end
if ~exist('timeField','var') || isempty(timeField)
    timeField = 3;
end
FlightNumField = 2;

if isempty(FlightNum) || isempty(LineNum) || isempty(LineTime) || isempty(deploymentNumber)
    
    if ~exist('lineFile','var')
        lineFile = [];
    end
    if ~exist(lineFile,'file')
        warning('RosettLinesToFile:invalidLineFIle','Line File %s does not exist or not specified!',lineFile);
        [lffile,lfpath] = uigetfile({'*.mat;*.txt'}, 'Select the file with project lines and flight numbers');
        lineFile = fullfile(lfpath,lffile);
    end
    if ~exist('deploymentNum','var')
        deploymentNumber = 1;
    else
        deploymentNumber = deploymentNum;
    end
    [~,~,lineFileExt] = fileparts(lineFile);
    if ~strcmpi(lineFileExt,'.mat')
        lineMatFile = convertLineCsv2mat(lineFile,[],[],[],false);
    else
        lineMatFile = lineFile;
    end
    load(lineMatFile,'FlightNum','LineNum','LineTime');
end
if exist('deploymentNum','var') && ~isempty(deploymentNum)
    if deploymentNum ~= deploymentNumber
        deploymentNumber = deploymentNum;
    end
end

if iscell(filename)
    Line = cell(size(filename));
    for lln = 1:numel(Line)
        filenameFields = strsplit(filename{lln},{'_','.'});
        Flight = filenameFields(FlightNumField);
        fileTime = datenum([filenameFields{dateField} filenameFields{timeField}],'yyyymmddHHMMSS');
        if fileTime < datenum(2014,1,1) || fileTime > datenum(2020,1,1)
            error('RosettaFlightToLine:invalidDateTimeFields','File Time out of Range, make sure dateField and TimeFields are correct, datetime = %s',...
                datestr(fileTime));
        end
        fileTime = matlab2unixtime(fileTime);
        gotLine = find(fileTime>=LineTime(:,1) & fileTime<=LineTime(:,2));
        if isempty(gotLine)
            Line{lln} = 'TBD';
        elseif numel(gotLine)>1
            possibleLines = LineNum(gotLine);
            Line{lln} = possibleLines{~strncmp(possibleLines,'X',1)};   % assign the file to "not-transit"
        else
            Line{lln} = LineNum{gotLine};
        end
    end
else
    filenameFields = strsplit(filename,{'_','.'});
    Flight = filenameFields(FlightNumField);
    fileTime = datenum([filenameFields{dateField} filenameFields{dateField}],'yyyymmddHHMMSS');
    gotLine = find(fileTime>=LineTime(:,1) & fileTime<=LineTime(:,2));
    if isempty(find(gotLine))
        Line = 'TBD';
    elseif numel(find(gotLine)>1)
        possibleLines = LineNum(gotLine);
        Line = possibleLines{~strncmp(possibleLines,'X',1)};   % assign the file to "not-transit"
    else
        Line = LineNum{gotLine};
    end
end

