function [Flight]  = RosettaLinesToFlight(Line,lineFile,deploymentNum)
% Returns flight names ('F10XX') for given line number for Rosetta, can
% take cell array as Line input. deploymentNum = 1, if not specified
persistent FlightNum LineNum deploymentNumber

if isempty(FlightNum) || isempty(LineNum) || isempty(deploymentNumber)
    
    if ~exist('lineFile','var')
        lineFile = [];
    end
    if ~exist(lineFile,'file')
        warning('RosettLinesToFile:invalidLineFIle','Line File %s does not exist or not specified!',lineFile);
        [lffile,lfpath] = uigetfile({'*.mat;*.txt'}, 'Select the file with project lines and flight numbers');
        lineFile = fullfile(lfpath,lffile);
    end
    if ~exist('deploymentNum','var')
        deploymentNumber = 1;
    else
        deploymentNumber = deploymentNum;
    end
    [~,~,lineFileExt] = fileparts(lineFile);
    if ~strcmpi(lineFileExt,'.mat')
        lineMatFile = convertLineCsv2mat(lineFile,[],[],[],false);
    else
        lineMatFile = lineFile;
    end
    load(lineMatFile,'FlightNum','LineNum');
end
if exist('deploymentNum','var') && ~isempty(deploymentNum)
    if deploymentNum ~= deploymentNumber
        deploymentNumber = deploymentNum;
    end
end
if iscell(Line)
    Flight = cell(size(Line));
    for lln = 1:numel(Line)
        Flight{lln} = num2str(deploymentNumber*1000+FlightNum(ismember(LineNum,Line{lln})),'F%4d');
    end
else
    Flight = num2str(deploymentNumber*1000+FlightNum(ismember(LineNum,Line)),'F%4d');
end

