function unixUTC = adjStdGPStoUTC(adjGPSTime)
% This function converted the adjusted standard gps time (used in a las
% file) to UTC time un unix seconds.
% From the las1.4 standard: 
%   The GPS Time is standard GPS Time (satellite GPS Time) minus 1e9.
%   The offset moves the time back to near zero to improve floating point 
%   resolution. The GPS time is number of seconds since Jan 6th 1980

% add 1e9 to bring to GPS Time and then move the reference to 1980;
gpsTime1970 = adjGPSTime + 1e9 + matlab2unixtime(datenum('1980-01-06','yyyy-mm-dd'));

% check to see leap second does not change withing the selected period
minLeapSecs = getGPSLeapSecs(min(gpsTime1970));
if minLeapSecs ~= getGPSLeapSecs(max(gpsTime1970))
    warning('adjStdGPStoUTC:jumpInTheMiddle',['Leap second offset changes within the time period - Lucky you!\n',...
        'Only one (lesser) leap second is applied to ensure timeseries continuity\n'])
end
unixUTC = gpsTime1970 - minLeapSecs;
end

