function [] = batchProcessLidarSurf(rootDir)
%% Parameters: rootDir the root directory of Lidar Data.
% This program methodically searches for all narrow_swath lidar data files in all
% directories in the path and extracts track over ground under the
% aircraft.

% It assumes the data of interest are located under directory name held by
% variable data_dir (default: narrow_swath);

% It assumes the gps trajectory mat file exists in the same direcotry as
% the las files with name 'gpsTrajectory.mat'

% This program need RW access to the data rootDir.
% Any previously processed data may be overwritten
% Tejendra Dhakal
% 09/06/2018
% LDEO, Columbia University

%%%********** Important*************%%%%%%%%%
% Change this to true to reprocess and overwrite exiting mat files.
overwriteOutput = false;

% options

% savePointcloud (optional): if true, saves a matfile with all data from
%                las files. false by default
savePointcloud = false;
% plotPointcloud (optional); if true, plots a decimated point cloud of all
%                           records and saves a png. true by default
plotPointcloud = true;

% you can also use other options -- see lasSurfElev.m
% make sure to pass the options in the lasSurfElev(..) function call

%%



persistent lastRootPath
if isempty(lastRootPath)
    lastRootPath = pwd;
elseif lastRootPath == 0
    lastRootPath = pwd;
end

if nargin <1
    if usejava('desktop')
        rootDir = uigetdir(lastRootPath,'Select a root Lidar directory');
    else
        error('batchProcessLidarSurf:missingArgs','Requires path to Lidar data')
    end
    lastRootPath = rootDir;
end

data_dir = 'narrow_swath';

% get a list of all directories in path
% This includes present dir '.' and parent dir '..'

fprintf('Working in %s  ..\n',rootDir);
close all;
pathParts = strsplit(rootDir,filesep);
if strcmpi(pathParts{end},data_dir)
    try
        lasSurfElev(rootDir,[rootDir,filesep,'gpsTrajectory.mat'],rootDir,[],savePointcloud,plotPointcloud,overwriteOutput);
    catch errMsg
        fprintf('batchProcessLidarSurf: Encountered an error\n');
        fprintf('%s\n',errMsg.message);
        fprintf('%s\n',errMsg.identifier);
        for jj = 1:numel(errMsg.stack)
            fprintf('In Function %s, Line %d\n',errMsg.stack(jj).name,errMsg.stack(jj).line)
        end
    end
end

dirList = dir(rootDir);
dirList = dirList([dirList.isdir]);
dirList = dirList([~ismember({dirList.name},'..')]);
dirList = dirList([~ismember({dirList.name},'.')]);
% recursively go through all folders and subfolders
for ddl = 1:numel(dirList)
    batchProcessLidarSurf([rootDir,filesep,dirList(ddl).name]);
end
warning('on','all');
end
