function [timeTick,lonTick,latTick,distTick] = diceTicks(lat,lon,timeutc,dist,displayAxes,dicefig,longPlot)
% Adds custom ticks on dice plots
if ~exist('dicefig','var')
    dicefig = gca();
elseif(isempty(dicefig))
    dicefig = gca();
end
if ~exist('longPlot','var')
    longPlot = false;
end

%% Remove existing tick labels
set(dicefig,'xticklabel',[]);
set(get(dicefig,'xlabel'),'String',[])
%% Get tick positions
yLims = get(dicefig,'ylim');
xLims = get(dicefig,'xlim');
yTicks = get(dicefig,'ytick');
xTicks = get(dicefig,'xtick');
% crude way of checking if x-axis is time or distance time is usually ~ 7e5
if max(xTicks) < 1000
    plotbydist = true;
else
    plotbydist = false;
end
% Interpolate lat,lon,time or distance to match
if plotbydist
    latTick = interp1(dist,lat,xTicks,'linear','extrap');
    lonTick = interpDegWithJumps(dist,lon,xTicks,'linear','extrap');
    timeTick = interp1(dist,timeutc,xTicks,'linear','extrap');
    distTick = xTicks;
else
    latTick = interp1(timeutc,lat,matlab2unixtime(xTicks),'linear','extrap');
    lonTick = interpDegWithJumps(timeutc,lon,matlab2unixtime(xTicks),'linear','extrap');
    distTick = interp1(timeutc,dist,matlab2unixtime(xTicks),'linear','extrap');
    distTick = distTick - distTick(1);
    timeTick = matlab2unixtime(xTicks);
end
%% get display options from displayAxes
if ismember('pos',displayAxes)
    posdisp = 1;
else
    posdisp = 0;
end
if ismember('dist',displayAxes)
    distdisp = 1;
else
    distdisp = 0;
end
if ismember('time',displayAxes)
    timedisp = 1;
else
    timedisp = 0;
end

%% Reset the XTicklabels onto multiple lines, 2nd line being twice of first
minY = min(yLims);
maxY = max(yLims);

reverseydir = strcmp(get(gca,'ydir'),'reverse');
reversexdir = strcmp(get(gca,'xdir'),'reverse');
% You will have to adjust the offset based on the size of figure

fontSize = get(gca,'fontsize');
if(longPlot)
    if(isunix)
        if range(distTick)>450
            fontSize = 2;
        elseif range(distTick)>350
            fontSize = 2;
        elseif range(distTick)>290
            fontSize = 3;
        elseif range(distTick)>200
            fontSize = 4;
        else
            fontSize = 5;
        end
        VerticalOffsetBottom = 35;
        VerticalOffsetTop = 20;
        if reversexdir
            HorizontalOffsetTop = .5;%-range(xLims)*0.0001;
            HorizontalOffsetBottom = .5;%-range(xLims)*0.0001;
        else
            HorizontalOffsetTop = -0.5;%range(xLims)*0.0001;
            HorizontalOffsetBottom = -0.5;%range(xLims)*0.0001;
        end
    else
        VerticalOffsetBottom = range(yTicks)*0.03;
        VerticalOffsetTop = range(yTicks)*0.02;
        if reversexdir
            HorizontalOffsetTop = -range(xLims)*0.001;
            HorizontalOffsetBottom = -range(xLims)*0.001;
        else
            HorizontalOffsetTop = range(xLims)*0.001;
            HorizontalOffsetBottom = range(xLims)*0.001;
        end
    end
else
    VerticalOffsetBottom = range(yLims)*0.06;
    VerticalOffsetTop = range(yLims)*0.03;
    % VerticalOffsetBottom = 1;
    % VerticalOffsetTop = 0.3;
    if reversexdir
        HorizontalOffsetTop = -range(xLims)*0.0225;
        HorizontalOffsetBottom = -range(xLims)*0.0225;
        % HorizontalOffset = -0.1;
    else
        HorizontalOffsetTop = range(xLims)*0.0225;
        HorizontalOffsetBottom = range(xLims)*0.0225;
        % HorizontalOffset = 0.1;
    end
end

latNS = @(x)char((x>=0)*78+(x<0)*83);
lonEW = @(x)char((x>=0)*69+(x<0)*87);
if ~strcmpi(slCharacterEncoding(),'Windows-1252')
    warning('diceTicks:wrongEncoding','Character encoding will be changed to "Windows-1252"')
    try
        slCharacterEncoding('Windows-1252');
    catch
        warning('diceTicks:encodingNotAvail','Windows-1252 Encoidng not Available. Some characters may be incorrect');
    end
end
for xx = 1:length(xTicks)
    
    % texthandle(xx) = text(xTicks(xx) - HorizontalOffset, minY - VerticalOffset, ['$$\begin{array}{c}',num2str(xTicks(xx)),'\textdegree','\\',num2str( 2*xTicks(xx)),'\end{array}$$'], 'Interpreter', 'latex')
    if posdisp
        postext = sprintf('%0.3f%c%c\n%0.3f%c%c',abs(latTick(xx)),char(176),latNS(latTick(xx)),abs(lonTick(xx)),char(176),lonEW(lonTick(xx)));
    else
        postext = [];
    end
    if distdisp
        disttext = sprintf('%0.1f km\n',distTick(xx));
    else
        disttext = [];
    end
    tickBottomText = [disttext postext];
    tickTopText = datestr(unix2matlabtime(timeTick(xx)),'HH:MM:SS');
    if reverseydir
        texthandle_bottom(xx) = text(xTicks(xx) - HorizontalOffsetBottom, maxY + VerticalOffsetBottom,tickBottomText,'fontweight','bold','fontsize',fontSize);
    else
        texthandle_bottom(xx) = text(xTicks(xx) - HorizontalOffsetBottom, minY - VerticalOffsetBottom,tickBottomText,'fontweight','bold','fontsize',fontSize);
    end
    if(timedisp)
        if reverseydir
            texthandle_top(xx) = text(xTicks(xx) - HorizontalOffsetTop, minY - VerticalOffsetTop,tickTopText,'fontweight','bold','fontsize',fontSize);
        else
            texthandle_top(xx) = text(xTicks(xx) - HorizontalOffsetTop, maxY + VerticalOffsetTop,tickTopText,'fontweight','bold','fontsize',fontSize);
        end
        set(texthandle_top(xx),'Tag','textXlabels');
        set(texthandle_top(xx),'UserData',[latTick', lonTick', timeTick', distTick';posdisp,posdisp,timedisp,distdisp]);
    end
    % {c} specifies that the elements of the different lines will be center
    % aligned. It may be replaced by {l} or {r} for left or right alignment
    set(texthandle_bottom(xx),'Tag','textXlabels');
    set(texthandle_bottom(xx),'UserData',[latTick', lonTick', timeTick', distTick';posdisp,posdisp,timedisp,distdisp]);
end
set(zoom(get(gca,'Parent')),'ActionPostCallback',@diceTicksCallBack)
set(pan(get(gca,'Parent')),'ActionPostCallback',@diceTicksCallBack)
set(get(gca,'Parent'),'CreateFcn',...
    'z = zoom(gcf);set(z,''ActionPostCallback'',''diceTicksCallBack'');p = pan(gcf);set(p,''ActionPostCallback'',''diceTicksCallBack'')')

