function diceTicksCallBack(varargin)
% find user data with textXlabels
dicefig = gca;
b = findobj(gca,'Type','text','Tag','textXlabels');
if isempty(b)
    warning('Cannot find user tick data')
    return;
else
    tickData = get(b(1),'UserData');
    lat = tickData(1:end-1,1);
    lon = tickData(1:end-1,2);
    timeutc = tickData(1:end-1,3);
    dist = tickData(1:end-1,4);
    posdisp = tickData(end,1);
    timedisp = tickData(end,3);
    distdisp = tickData(end,4);
end
%% Remove existing tick labels
delete(b);

%% get the current ticks
%% Get ticks
yLims = get(dicefig,'ylim');
yTicks = get(dicefig,'ytick');
xTicksOld = get(dicefig,'xtick');
% x axis uses custom ticks, get the limits instead
xLims = get(dicefig,'xlim');
xTicks = linspace(xLims(1),xLims(2),numel(xTicksOld));
set(dicefig,'xtick',xTicks);
set(dicefig,'xticklabel',[]);
% crude way of checking if x-axis is time or distance time is usually ~ 1e9
if max(xTicks) < 10000
    plotbydist = true;
else
    plotbydist = false;
end

% Interpolate lat,lon,time or distance to match
if plotbydist
    latTick = interp1(dist,lat,xTicks,'linear','extrap');
    lonTick = interpDegWithJumps(dist,lon,xTicks,'linear','extrap');
    timeTick = interp1(dist,timeutc,xTicks,'linear','extrap');
    distTick = xTicks;
else
    latTick = interp1(timeutc,lat,matlab2unixtime(xTicks),'linear','extrap');
    lonTick = interpDegWithJumps(timeutc,lon,matlab2unixtime(xTicks),'linear','extrap');
    distTick = interp1(timeutc,dist,matlab2unixtime(xTicks),'linear','extrap');
    distTick = distTick - distTick(1);
    timeTick = matlab2unixtime(xTicks);
end

%% Reset the XTicklabels onto multiple lines, 2nd line being twice of first

minY = min(yLims);
maxY = max(yLims);

reverseydir = strcmp(get(gca,'ydir'),'reverse');
reversexdir = strcmp(get(gca,'xdir'),'reverse');
% Relative offset  for tickslabels

VerticalOffsetBottom = range(yTicks)*0.06;
VerticalOffsetTop = range(yTicks)*0.03;
if reversexdir
    HorizontalOffsetTop = -range(xLims)*0.0225;
    HorizontalOffsetBottom = -range(xLims)*0.0225;
else
    HorizontalOffsetTop = range(xLims)*0.0225;
    HorizontalOffsetBottom = range(xLims)*0.0225;
end

    
latNS = @(x)char((x>=0)*78+(x<0)*83);
lonEW = @(x)char((x>=0)*69+(x<0)*87);
if ~strcmpi(slCharacterEncoding(),'Windows-1252')
    warning('diceTicks:wrongEncoding','Character encoding will be changed to "Windows-1252"')
    try
        slCharacterEncoding('Windows-1252');
    catch
        warning('diceTicks:encodingNotAvail','Windows-1252 Encoidng not Available. Some characters may be incorrect');
    end
end

for xx = 1:length(xTicks)
    
    % texthandle(xx) = text(xTicks(xx) - HorizontalOffset, minY - VerticalOffset, ['$$\begin{array}{c}',num2str(xTicks(xx)),'\textdegree','\\',num2str( 2*xTicks(xx)),'\end{array}$$'], 'Interpreter', 'latex')
    if posdisp
        postext = sprintf('%0.3f%c%c\n%0.3f%c%c',abs(latTick(xx)),char(176),latNS(latTick(xx)),abs(lonTick(xx)),char(176),lonEW(lonTick(xx)));
    else
        postext = [];
    end
    if distdisp
        disttext = sprintf('%0.1f km\n',distTick(xx));
    else
        disttext = [];
    end
    tickBottomText = [disttext postext];
    tickTopText = datestr(unix2matlabtime(timeTick(xx)),'HH:MM:SS');
    if reverseydir
        texthandle_bottom(xx) = text(xTicks(xx) - HorizontalOffsetBottom, maxY + VerticalOffsetBottom,tickBottomText,'fontweight','bold');
    else
        texthandle_bottom(xx) = text(xTicks(xx) - HorizontalOffsetBottom, minY - VerticalOffsetBottom,tickBottomText,'fontweight','bold');
    end
    if(timedisp)
        if reverseydir
            texthandle_top(xx) = text(xTicks(xx) - HorizontalOffsetTop, minY - VerticalOffsetTop,tickTopText,'fontweight','bold');
        else
            texthandle_top(xx) = text(xTicks(xx) - HorizontalOffsetTop, maxY + VerticalOffsetTop,tickTopText,'fontweight','bold');
        end
        set(texthandle_top(xx),'Tag','textXlabels');
        set(texthandle_top(xx),'UserData',[latTick', lonTick', timeTick', distTick';posdisp,posdisp,timedisp,distdisp]);
    end
    % {c} specifies that the elements of the different lines will be center
    % aligned. It may be replaced by {l} or {r} for left or right alignment
    set(texthandle_bottom(xx),'Tag','textXlabels');
    set(texthandle_bottom(xx),'UserData',[latTick', lonTick', timeTick', distTick';posdisp,posdisp,timedisp,distdisp]);
end
%% Lets check and see if there is a scale axis
allAxes = get(get(dicefig,'Parent'),'Children');
if numel(allAxes) >=2
    scaleAx = findobj(get(dicefig,'Parent'),'Type','axes','Tag','dicefigXscale');
    rangeXaxis = range(xLims);
    numXticks = numel(xTicksOld);
    dicefigSize = get(dicefig,'Position');
    %     xScale = min(ceil((rangeXaxis/numXticks)/5)*5,ceil(rangeXaxis/4));
    xScale = rangeXaxis/(numXticks-1);
    set(scaleAx,'Position',[dicefigSize(3)*(numXticks-3)/(numXticks-1)+dicefigSize(1) 0.15 dicefigSize(3)/(numXticks - 1) 1e-12]);
    set(scaleAx,'xlim',[0 xScale],'xtick',[0 xScale/2 xScale],...
        'xtickLabel',{'0','',num2str(xScale,'%.1f km')});
    set(scaleAx,'fontweight','bold');
end
set(get(dicefig,'Parent'),'CurrentAxes',dicefig);
end


