function [] = findAndFixRadarPicks(rootDir)
% Parameters: rootDir the root directory of Level1a/level2a or level3 Sir
% or Dice data.
% This program methodically searches for all radar pick files (dice and
% sir) and calls fixRadarPicks to bring all picks to latest version
% This program need RW access to the data rootDir.
% The program will look for .mat file and skip the files
% in the list.

% Node: Any data processed on or after 05/31/2017 using the up-to-date Dice
% processing code DOES NOT require fixing.

% Tej Dhakal
% 09/23/2018
% LDEO, Columbia University

%% Persistent lastFilePath variable sotes recently used path for use as starting path
persistent lastRootPath
if isempty(lastRootPath)
    lastRootPath = pwd;
elseif lastRootPath == 0
    lastRootPath = pwd;
end

if nargin <1
    rootDir = [];
end

if isempty(rootDir) || ~exist(rootDir,'dir')
    if usejava('desktop')
        rootDir = uigetdir(lastRootPath,'Select Data root directory to fix');
    else
        error('Requires path to Data as argument')
    end
end
lastRootPath = rootDir;

logFile = ['fixPicksLog',datestr(now,'_yyyymmdd_hhMMss'),'.log'];
diary(logFile);

% get a list of all files and directories in the path
% This includes present dir '.' and parent dir '..'
fprintf('findAndFixRadarPicks: Working in %s ..\n',rootDir);
backupFiles = dir([rootDir,filesep,'*fixPicks_bak']);
if ~isempty(backupFiles)
    fprintf('findAndFixRadarPicks: Found %d backup files\nRestoring..\n',numel(backupFiles));
    for bff = 1:numel(backupFiles)
        [~,filenameOnly,~] = fileparts(backupFiles(bff).name);
        movefile([rootDir,filesep,backupFiles(bff).name],[rootDir,filesep,filenameOnly,'.mat']);
        fprintf('findAndFixRadarPicks: %s\n',[filenameOnly,'.mat']);
    end
    fprintf('findAndFixRadarPicks: Done!\n');
end
fList = dir([rootDir,filesep,'*_Picks.mat']);
% Fix the files in the current diretory
if ~isempty(fList)
    fixStatus = false(numel(fList),1);
else
   fixStatus = false;
end
for ff = 1:numel(fList)
    fixStatus(ff) = fixRadarPicks([rootDir,filesep,fList(ff).name]);
end
fprintf('findAndFixRadarPicks: Done!\n');
%stop the diary and move the current log file to the
diary off;

if any(fixStatus) 
    [~,logFileNameOnly,logFileExtOnly] = fileparts(logFile);
    logOutDir = [rootDir,filesep,'..',filesep,'log',filesep];
    if ~exist(logOutDir,'dir')
        mkdir(logOutDir);
    end
    movefile(logFile,[logOutDir,filesep,logFileNameOnly,logFileExtOnly]);
else
    delete(logFile);
end
% work through all the subdirectories
dirList = dir(rootDir);
% exclude all files in the dir
dirList = dirList([dirList.isdir]);
% exclude current and last dir as well as some known directory names
dirList = dirList([~ismember({dirList.name},'..')]);
dirList = dirList([~ismember({dirList.name},'.')]);
dirList = dirList([~ismember({dirList.name},'log')]);
dirList = dirList([~ismember({dirList.name},'txt')]);
dirList = dirList([~ismember({dirList.name},'png')]);
dirList = dirList([~ismember({dirList.name},'jpg')]);
dirList = dirList([~ismember({dirList.name},'pdf')]);
dirList = dirList([~ismember({dirList.name},'bin')]);
dirList = dirList([~ismember({dirList.name},'raw')]);
dirList = dirList([~ismember({dirList.name},'pnt')]);
dirList = dirList([~ismember({dirList.name},'gravity')]);
dirList = dirList([~ismember({dirList.name},'doc')]);
dirList = dirList([~ismember({dirList.name},'lidar')]);
dirList = dirList([~ismember({dirList.name},'magnetics')]);
dirList = dirList([~ismember({dirList.name},'optics')]);
dirList = dirList([~ismember({dirList.name},'auxiliary')]);

% recursively calls itself until no subdirectories available
for ddl = 1:numel(dirList)
    findAndFixRadarPicks([rootDir,filesep,dirList(ddl).name]);
end
end
