function [] = findAndGenerateGpsMatFiles(gpsLevel1Dir,gpsWildCard)
% This program methodically searches for all level1 GPS text files and
% converts them to mat files
% This program need RW access to the data gpsLevel1Dir.
% Any previously fixed files are replaced with the newly generated files
% Parameters:
% GPSLEVEL1DIR: path to the GPS level1 Data.
% GPSWILDCARD: (optional) filter for GPS files to process
% Tejendra Dhakal
% 06/13/2016
% LDEO, Columbia University

if nargin <1
    if usejava('desktop')
        gpsLevel1Dir = uigetdir('Select GPS Level1 Dir');
    else
        error('Requires path to Gps Level1 directory as argument')
    end
elseif isempty(gpsLevel1Dir) || exist(gpsLevel1Dir,'dir')~= 7
    if usejava('desktop')
        gpsLevel1Dir = uigetdir('Select GPS Level1 Dir');
    else
        error('Requires path to Gps Level1 directory as argument')
    end
end

if ~exist('gpsWildCard','var')
    gpsWildCard = '*FINAL*.txt';
elseif isempty(gpsWildCard)
    warning('Invalid Wildcard')
    gpsWildCard = '*FINAL*.txt';
end
% Get a list of all GPS Final files and directories in path
% This includes present dir '.' and parent dir '..'
fprintf('Working in %s..\n',gpsLevel1Dir);
fList = dir([gpsLevel1Dir,filesep,gpsWildCard]);
for ff = 1:numel(fList)
    convertGPStxt2mat([gpsLevel1Dir,filesep,fList(ff).name],[],[],[],true);
end
dirList = dir(gpsLevel1Dir);
dirList = dirList([dirList.isdir]);
dirList = dirList([~ismember({dirList.name},'..')]);
dirList = dirList([~ismember({dirList.name},'.')]);
% recursively go through all folders and subfolders
for ddl = 1:numel(dirList)
    findAndGenerateGpsMatFiles([gpsLevel1Dir,filesep,dirList(ddl).name],gpsWildCard);
end
end
