function [fixedlon] = fixLonJumpError(lon,time)
%% Address a specific issue where waypoint puts an erroneous Longitude during a meridian crossing

if any(any(lon<0))
    lon = wrapTo360(lon);
end

dLonInd = find(abs(diff(lon))>2);    % Any jump more than 1 deg
dTimeInd = find(abs(diff(time)>2));      % Any jump more than 1 s
dLonInd = dLonInd(~ismember(dLonInd,dTimeInd));     % find all the longitude indices that are not same as time indices
dLonInd = unique([dLonInd(dLonInd ==1); dLonInd(dLonInd(1:end-1)+1 == dLonInd(2:end));dLonInd(dLonInd ==numel(lon)-1)]);
if ~isempty(dLonInd)
    warning('fixLonJumpError:LONJumpsInData','Longitude Jump found')
    for ljj = 1: numel(dLonInd)
        fprintf('%s\n',datestr(unix2matlabtime(time(dLonInd(ljj)))));
    end
end
midInds = dLonInd(dLonInd > 1 & dLonInd<numel(lon)-1);
lon(midInds+1) = 0.5*(lon(midInds) + lon(midInds+2));
% Take care of the case when the jump is the first or last data point
if any(dLonInd ==1)
    lon(1) = interpDegWithJumps(time(2:3),lon(2:3),time(1),'linear','extrap');
end
if any(dLonInd ==dLonInd<numel(lon))
    lon(end) = interpDegWithJumps(time(end-2:end-1),lon(end-2:end-1),time(end),'linear','extrap');
end
if any(any(lon>180))
    lon = wrapTo180(lon);
end
fixedlon = lon;
end