% Picks Fixer
% This functions brings all the Dice and Sir picks in line with the latest
% version including all same variable names and features..

% Some of the noticable differences found in the picks are:
%  1. Time variable named as GPS_time in earlier picks and unixTime later
%  2. userRefAlt not available in older picks
%  3. Motion compensation info not available in older picks
%  4. PickerVersion variable not available in older picks
%  5. Notes structure doesn't include :
%       Notes.PickedOnTime
%       Notes.Campaign_Proj
%       Notes.Flight_Line
%       Notes.SourceProdLevel
%       Notes.Sensor
%       Notes.PickType
%       Notes.Platform

function [fixed] = fixRadarPicks(inputfile)
fileFieldSep = '_';
if nargin<1
    if usejava('desktop')
        [file,path] = uigetfile('*.mat','Select a dice level2a or Picks file to fix');
        inputfile = fullfile(path,file);
     else
        error('fixSurfElev:InvalidPath','Requires full level2a or Picks file as argument')
    end
end

if strcmpi(get(0,'Diary'),'on')
    logFile = get(0,'DiaryFile');
    localDiary = false;
else
    logFile = ['fixPicksLog',datestr(now,'yyyymmdd_hhMMss.log')];
    diary(logFile);
    localDiary = true;
    cleanLogs = onCleanup(@() cleanLogFileOnCrash(logFile));
end

TxInd = 318;
cAir = 299792458;
fixed = false;
doFix = 0;
[filedirpath,filenameonly,~] = fileparts(inputfile);
fileNameParts = strsplit(filenameonly,fileFieldSep);

if ~any(ismember(fileNameParts,'Picks'))
    return;
end

if any(ismember({'1usCh1';'1usCh2';'3usCh1';'3usCh2';...
        '10usCh1';'10usCh2';'dice';'Dice';'DICE'},fileNameParts))
    dicefile = true;
else
    dicefile = false;
end

save_eval = 'save(inputfile,';

varlist = whos('-file',inputfile);
if ~ismember('unixTime',{varlist.name})
    load(inputfile,'GPS_time');
    unixTime = GPS_time;
    GPS_time = [];
    doFix = doFix + 1;
    save_eval = [save_eval,'''unixTime'',''GPS_time'','];
end
if ismember('MultipleBright',{varlist.name})
    mbind = find(ismember({varlist.name},'MultipleBright'));
    if varlist(mbind).complex
        load(inputfile,'MultipleBright');
        MultipleBright = abs(MultipleBright);
        doFix = doFix + 1;
        save_eval = [save_eval,'''MultipleBright'','];
    end
else
    if exists('unixTime','var')
        unixtimesize = size(unixTime);
    else
        unixtimesize = varlist(find(ismember({varlist.name},'unixTime'))).size;
    end
    doFix = doFix + 1;
    save_eval = [save_eval,'''MultipleBright'','];
end

if ~ismember('motionComp',{varlist.name})
    if dicefile
        motionComp = false;
    else
        motionComp = true;
    end
    doFix = doFix + 1;
    save_eval = [save_eval,'''motionComp'','];
end

if ~ismember('userRefAlt',{varlist.name})
    if motionComp
        userRefAlt = 2500;
    else
        userRefAlt = NaN;
    end
    doFix = doFix + 1;
    save_eval = [save_eval,'''userRefAlt'','];
end

if ~ismember('PickerVersion',{varlist.name})
    PickerVersion = 1.0;
    doFix = doFix + 1;
    save_eval = [save_eval,'''PickerVersion'','];
end

load(inputfile,'Notes');

%       Notes.PickedOnTime
%       Notes.Campaign_Proj
%       Notes.Flight_Line
%       Notes.SourceProdLevel
%       Notes.Sensor
%       Notes.PickType
%       Notes.Platform
lastdoFix = doFix;
if ~isfield(Notes,'Campaign_Proj')
    Notes.Campaign_Proj = fileNameParts{1};
    doFix = doFix + 1;
end
if ~isfield(Notes,'Flight_Line')
    Notes.Flight_Line = fileNameParts{2};
    doFix = doFix + 1;
end
if ~isfield(Notes,'SourceProdLevel')
    level_ind = find(strncmpi(fileNameParts,'level',5));
    if numel(level_ind)==1
        Notes.SourceProdLevel = fileNameParts{level_ind};
    else
        Notes.SourceProdLevel = 'Unknown';
    end
    doFix = doFix + 1;
end
if ~isfield(Notes,'Sensor')
    if dicefile
        Notes.Sensor = 'DICE';
    else
        Notes.Sensor = 'SIR';
    end
    doFix = doFix + 1;
end
if ~isfield(Notes,'PickType')
    dirLevels = strsplit(filedirpath,filesep);
    pickDir = dirLevels{end-1};
    pickDirParts = strsplit(pickDir,fileFieldSep);
    try
        % using datetime instead of datenum generate error if datestring in
        % not valid
        pickDate = datetime(pickDirParts{3},'InputFormat','yyyyMMdd');
        if pickDate > datetime('2013','InputFormat','yyyy') && ...
                pickDate < datetime('now')
            pickDate = matlab2unixtime(datenum(pickDate));
        else
            pickDate = NaN;
        end
    catch
        pickDate = NaN;
    end
    if numel(pickDirParts) == 4 && ...
            numel(pickDirParts{1}) == 2 &&...
            ~isnan(pickDate)
        Notes.PickType = pickDirParts{2};
        doFix = doFix + 1;
    end
end
if ~isfield(Notes,'PickedOnTime')
    Notes.PickedOnTime = pickDate;
    doFix = doFix + 1;
end
if ~isfield(Notes,'Platform')
    Notes.Platform = 'Icepod';
    doFix = doFix + 1;
end
if doFix > lastdoFix
    save_eval = [save_eval,'''Notes'','];
end

save_eval = [save_eval,'''-append'')'];

try
    if doFix==0
        fprintf('fixRadarPicks: %s does not require fixing\n',inputfile);
        fixed = true;
    else
        bakFile = [inputfile,'-fixPicks_bak'];
        copyfile(inputfile,bakFile);
        
        eval(save_eval);
        delete(bakFile);
        
        fixed = true;
        fprintf('fixRadarPicks: %s Radar picks file fixed\n',inputfile);
    end
    if localDiary
        if ~exist(logPath,'dir')
            mkdir(logPath);
        end
        diary off;
        movefile(logFile,[logPath,filesep,logFile]);
        warning('on','all');
        clear('cleanLogs');
    end   
catch errorid
    disp('Caught an Error!!')
    disp(errorid.identifier)
    disp(errorid.message)
    for jj = 1:numel(errorid.stack)
        fprintf('In Function %s, Line %d\n',errorid.stack(jj).name,errorid.stack(jj).line)
    end
    warning('on','all');
    return;
end
end