function [leapSec,changeTimes] = getGPSLeapSecs(unixsecs)

%% Initialize variables.
if nargin<1
    matlabTime = now();
else
    matlabTime = unix2matlabtime(unixsecs);
end
persistent leapOffset jumpDateTime
if isempty(leapOffset) || isempty(jumpDateTime)
    
    %% Initialize variables.
    filename = 'tai-utc.dat';
    foundUpdatedFile = false;
    try
        str = urlread('http://maia.usno.navy.mil/ser7/tai-utc.dat');
        foundUpdatedFile = true;
    catch
        foundUpdatedFile = false;
        fprintf('Using local file\n');
    end
    if foundUpdatedFile
        try
        [filepath,~,~] = fileparts(mfilename('fullpath'));
        fid1 = fopen([filepath,filesep,filename],'w');
        wcleaner = onCleanup(@() fclose(fid1));
        fprintf(fid1,'%s',str);
        clear('wcleaner');
        catch
            fprintf('Using local file\n');
            foundUpdatedFile = false;
            [filepath,~,~] = fileparts(mfilename('fullpath'));
        end
    else
        [filepath,~,~] = fileparts(mfilename('fullpath'));
    end
    %% Read columns of data as strings:
    % For more information, see the TEXTSCAN documentation.
    formatSpec = '%5s%4s%3s%4s%10s%10s%6s%[^\n\r]';
    
    %% Open the text file.
    if(foundUpdatedFile)
        fileID = fopen(filename,'r');
    else
        fileID = fopen([filepath,filesep,filename]);
    end
    cleaner = onCleanup(@()fclose(fileID));
    %% Read columns of data according to format string.
    % This call is based on the structure of the file used to generate this
    % code. If an error occurs for a different file, try regenerating the code
    % from the Import Tool.
    dataArray = textscan(fileID, formatSpec, 'Delimiter', '', 'WhiteSpace', '',  'ReturnOnError', false);
    
    %% Close the text file.
    clear cleaner;
    
    %% Convert the contents of columns containing numeric strings to numbers.
    % Replace non-numeric strings with NaN.
    raw = repmat({''},length(dataArray{1}),length(dataArray)-1);
    for col=1:length(dataArray)-1
        raw(1:length(dataArray{col}),col) = dataArray{col};
    end
    numericData = NaN(size(dataArray{1},1),size(dataArray,2));
    
    for col=[1,3,7]
        % Converts strings in the input cell array to numbers. Replaced non-numeric
        % strings with NaN.
        rawData = dataArray{col};
        for row=1:size(rawData, 1)
            % Create a regular expression to detect and remove non-numeric prefixes and
            % suffixes.
            regexstr = '(?<prefix>.*?)(?<numbers>([-]*(\d+[\,]*)+[\.]{0,1}\d*[eEdD]{0,1}[-+]*\d*[i]{0,1})|([-]*(\d+[\,]*)*[\.]{1,1}\d+[eEdD]{0,1}[-+]*\d*[i]{0,1}))(?<suffix>.*)';
            try
                result = regexp(rawData{row}, regexstr, 'names');
                numbers = result.numbers;
                
                % Detected commas in non-thousand locations.
                invalidThousandsSeparator = false;
                if any(numbers==',')
                    thousandsRegExp = '^\d+?(\,\d{3})*\.{0,1}\d*$';
                    if isempty(regexp(thousandsRegExp, ',', 'once'))
                        numbers = NaN;
                        invalidThousandsSeparator = true;
                    end
                end
                % Convert numeric strings to numbers.
                if ~invalidThousandsSeparator
                    numbers = textscan(strrep(numbers, ',', ''), '%f');
                    numericData(row, col) = numbers{1};
                    raw{row, col} = numbers{1};
                end
            catch me
            end
        end
    end
    
    %% Split data into numeric and cell columns.
    rawNumericColumns = raw(:, [1,3,7]);
    rawCellColumns = raw(:, 2);
    
    
    %% Allocate imported array to column variable names
    jumpDate = cell2mat(rawNumericColumns(:, 1));
    jumpMon = rawCellColumns(:, 1);
    jumpDay = cell2mat(rawNumericColumns(:, 2));
    
    leapOffset = cell2mat(rawNumericColumns(:, 3))-19;
    leapOffset(leapOffset<0) = 0;
    for dd = 1:numel(jumpDate)
        jumpDateTime(dd) = datenum([num2str(jumpDate(dd)),jumpMon{dd},num2str(jumpDay(dd),'%02d')],'yyyymmmdd');
    end
end
leapSec = leapOffset(find(jumpDateTime<=matlabTime,1,'last'));
changeTimes = matlab2unixtime(jumpDateTime);
end
