function y = interpDegWithJumps(x1,y1,x,method,extrapval)
%interpDegWithJumps 1-D interpolation of angles in degrees that have jumps
% from = -180 to 180 or 0 to 360 using linear interpolation.
%   y = INTERP1(x1,y1,x) interpolates to find y, the values of the
%   underlying function y=F(x) at the query points x.
%   x1  and y1 must be a vectors of equal lengths
% 03/07/2017 - Tej Dhakal
if nargin <3
    error('interpDegWithJumps:TooFewArgs','Too few arguments');
elseif nargin<4
    if ~isvector(x1) || ~isvector(y1)
        error('interpDegWithJumps:TableNotVectors','x1 and y1 must be vectors')
    elseif numel(x1)~=numel(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    end
    method = 'linear';
elseif nargin<5
    if ~isvector(x1) || ~isvector(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    elseif numel(x1)~=numel(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    end
    if isempty(method) || isnumeric(method)
        warning('interpDegWithJumps:InvalidMethod','Invalid method type, using ''linear''');
        method = 'linear';
    end
elseif nargin ==5
    if ~isvector(x1) || ~isvector(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    elseif numel(x1)~=numel(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    end
    if isempty(method) || isnumeric(method)
        warning('interpDegWithJumps:InvalidMethod','method should be a char array, using ''linear''');
        method = 'linear';
    end
    if isempty(extrapval) || isnumeric(extrapval)
        warning('interpDegWithJumps:InvalidExtrapval','extrap value should be a char array, using default');
        clear extrapval;
    end
elseif nargin>5
    warning('interpDegWithJumps:TooManyArgs','Too many arguments, extra arguments will be ignored');
    if ~isvector(x1) || ~isvector(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    elseif numel(x1)~=numel(y1)
        error('interpDegWithJumps:TableNotEqual','x1 and y1 must be equal sizes')
    end
    if isempty(method) || isnumeric(method)
        warning('interpDegWithJumps:InvalidMethod','Invalid method type, using ''linear''');
        method = 'linear';
    end
    if isempty(extrapval) || isnumeric(extrapval)
        warning('interpDegWithJumps:InvalidExtrapval','Invalid method type, using ''linear''');
        clear extrapval;
    end
end

%% determine if y1 is +/-180 wrapped of 0-360 wrapped
if any(y1<0)
    returnWrapType = 1; % 180 wrapped
else
    returnWrapType = 2; % 360 wrapped
end
%% Lets get to work
if exist('extrapval','var')
% Lets check if there is a jump of 60 degrees or more in y1
if(returnWrapType == 1)
    if any(abs(diff(y1))>60)
        y = wrapTo180(interp1(x1,wrapTo360(y1),x,method,extrapval));
    else
        y = interp1(x1,y1,x,method,extrapval);
    end
else
    if any(abs(diff(y1))>60)
        y = wrapTo360(interp1(x1,wrapTo180(y1),x,method,extrapval));
    else
        y = interp1(x1,y1,x,method,extrapval);
    end
end
else
    % Lets check if there is a jump of 60 degrees or more in y1
if(returnWrapType == 1)
    if any(abs(diff(y1))>60)
        y = wrapTo180(interp1(x1,wrapTo360(y1),x,method));
    else
        y = interp1(x1,y1,x,method);
    end
else
    if any(abs(diff(y1))>60)
        y = wrapTo360(interp1(x1,wrapTo180(y1),x,method));
    else
        y = interp1(x1,y1,x,method);
    end
end
end
end
