function dataout=intuitive_lowpass(datain,minwavelength)
% Function by Mike Wolovick, updated on 2/25/2011

% This function lowpass filters an input in 1D by convolving it with a 
% gaussian weighting function.  

% The standard deviation of the gaussian is one-half the minwavelength. ie,
% full width at half max (FWHM) is roughly minwavelength.

% Minwavelength must be in terms of number of samples of datain. 

% A linear best-fit is removed before the data are filtered, then added
% back in at the end. 

% Edge effects are minimized by adding a buffer to either side of the input
% equal to the value at the endpoints.  This is done after the best-fit is
% removed.  IE, the boundary condition is an extrapolation of the endpoint
% values based on the best-fit slope of the entire input.  

% The function assumes that the input is evenly spaced.

rowvec=0;
if isscalar(datain)==1
    error('Data Input must be a vector or a matrix.')
elseif size(minwavelength,1)~=1 || size(minwavelength,2)~=1
    error('Minimum Wavelength must be a scalar.')
elseif size(datain,1)==1
    rowvec=1;
    datain=datain';
end
L=length(datain);
integer_wavelength=round(minwavelength);
stdev=.5*minwavelength;
Lbig=L+6*integer_wavelength;
xs=linspace(1,Lbig,Lbig)';
xcent=Lbig/2;
A=[ones(L,1),linspace(1,L,L)'];
equation=(A'*A)\A'*datain;
bestline=equation(1)+equation(2)*linspace(1,L,L)';
datain=datain-bestline;
dataspread=zeros(Lbig,1);
dataspread(1:3*integer_wavelength)=datain(1);
dataspread(3*integer_wavelength+1:end-3*integer_wavelength)=datain;
dataspread(end-3*integer_wavelength+1:end)=datain(end);
filter=exp(-.5*((xs-xcent)/stdev).^2);
filter=filter/sum(filter);
filtertrans=fft(filter);
datatrans=fft(dataspread);
dataout=fftshift(ifft(filtertrans.*datatrans));
dataout=dataout(3*integer_wavelength:end-3*integer_wavelength-1);
dataout=dataout+bestline;
if rowvec==1
    dataout=dataout';
end
