function newStruct = mergeStruct(struct1,struct2)
% merge structures with different fieldnames
%   X = mergeStruct(S1,S2) merges structures S1 and S2
%   into one new structure X. X contains all fields present in S1 and S2.
%   In case of a common field the value in S1 is retained.

if(~isstruct(struct1) || ~isstruct(struct2))
    error('mergeStruct:InvalidArgs','Both arguments must be strucs\n')
end
if(numel(struct1)~=1 || numel(struct2)~=1)
    error('mergeStruct:InvalidStructSize','Cannot Process Struct Arrays at this time!\n')
end

 fieldsInStruct1 = fieldnames(struct1);              % fields in struct1
 fieldValuesStruct1 = struct2cell(struct1);
 fieldsInStruct2 = fieldnames(struct2);              % fields in struct2
 fieldValuesStruct2 = struct2cell(struct2);
 commonFields = ismember(fieldsInStruct2,fieldsInStruct1);  % index of fields in 2 those are not already in 1
newStruct = orderfields(cell2struct(cat(1,fieldValuesStruct1,fieldValuesStruct2(~commonFields)),...
    cat(1,fieldsInStruct1,fieldsInStruct2(~commonFields)),1));   % adds new words
if(~isempty(find(commonFields)))
   warning('mergeStruct:duplicateFields','Duplicate Fields "%s" found!\n Value from first structure will be retained\n',fieldsInStruct2{commonFields})
end
