function[] = stitchAllPicks(inputdir,outputdir,lineFile)
% this funciton cycles through all the Pick mat files in matpath and
% stitches various variables together to create a single file
% default values if not specified:

%% Some constants and settings - Change these to adapt to file format changes

% The code looks at the file names and determines the sensor type as long
% as the file name has 'DICE' or 'SIR' in it. otherwise uncomment the
% following line.

% pickDice = true;    % true for Dice, false for Sir.

% File name stuff
stitchedSuffix = 'StitchedPicks';
outputsuffix = 'Picks';     % text to put at the end of the filename


fileFieldSep = '_';     % Separator for different field in file name field
CampaignField = 1;      % Field number for Campaign or Project
FlightNumField = 2;     % Field number for Flight or Line
outFileDateFormat = 'yyyymmdd';
outFileTimeFormat = 'HHMMSS';

% File field identifiers. Change these to match the file name structure

dateField = 3;          % Field number for date
timeField = 4;          % Field number for time

chanField = 5;          % Field number for dice channel tag
diceLevelField = [];     % Field number for dice product level
diceSensorField = [];    % Field number for dice Sensor Name
diceFileNumField = 6;   % Field number for dice file number

sirLevelField = 5;      % Field number for sir product level
sirSensorField = 6;     % Field number for sir sensor Name
sirFileNumField = 7;    % Field number for file number

% Constants
% Velocities:
c_air=3e8;     %m/s
c_ice=1.68e8;  %m/s

% Characteristic Wavelengths:
xwavelength=50;  %m
ywavelength=5;  %m

%% Less likely to change
% Flight stuff
referenceElev = 2500/3.28;  % m, Older picks don't have this in the mat file
motionCompensated = true;          %  Older picks don't have this in the mat file

% diceChannels
diceChans = [1,2,3,4];
diceChanAttbr = {'3usCh1','3usCh2','1usCh1','1usCh2'};
% Campaign Info
% This information is lost once we get into the Line stage -almost always 1
deploymentNum = 1;

%%

% House Keeping

% startfile 0, endfile inf processed all available file
% otherwise these are file sequence numbers (from file name)
startfile(diceChans) = 0;
endfile(diceChans) = inf;

if nargin<1
    inputdir = [];
    outputdir = [];
    lineFile = [];
elseif nargin<2
    outputdir = [];
    lineFile = [];
elseif nargin<3
    lineFile = [];
end

if ~exist('startfile','var')
    startfile(diceChans) = 0;
end
if ~exist('endfile','var')
    endfile(diceChans) = inf;
end

if ~isempty(inputdir)
    if ~(inputdir(end) == filesep)
        inputdir = [inputdir filesep];
    end
    if ~exist(inputdir,'dir')
        inputdir = [];
        warning('stitchAllPicks:invalidInputDir','Input directorey %s does not exist!',inputdir);
    end
end

if  isempty(inputdir)
    inputdir = uigetdir(pwd,'Select mat dir for picks to combine');
    if isempty(inputdir) || numel(inputdir)<2
        error('genStitchedProds:noDirSelected','Aborted: no directory selected');
    end
    inputdir = [inputdir filesep];
end

if ~exist(lineFile,'file')
    warning('stitchAllPicks:invalidLineFIle','Line File %s does not exist!',lineFile);
    [lffile,lfpath] = uigetfile({'*.mat;*.txt'}, 'Select the file with project lines and flight numbers');
    lineFile = fullfile(lfpath,lffile);
end
[~,~,lineFileExt] = fileparts(lineFile);
if ~strcmpi(lineFileExt,'.mat')
    lineMatFile = convertLineCsv2mat(lineFile,[],[],[],false);
else
    lineMatFile = lineFile;
end

load(lineMatFile,'FlightNum','LineNum','LineTime');

if isempty(outputdir)
    outputdir = [inputdir,filesep,'Stitched',filesep];
elseif outputdir(end) ~= filesep
    outputdir = [outputdir,filesep];
end


if ~exist(outputdir,'dir')
    mkdir(outputdir);
end
%%
inputDicefiles = cell(size(diceChans));
numDiceInputFiles = zeros(size(diceChans));
if ~exist('pickDice','var')
    %determine sensor to stitch
    for dckk = diceChans
        if ~isempty(diceSensorField)
            inputDicefiles{dckk}=dir([inputdir,filesep,'*',diceChanAttbr{dckk},'*DICE*_',outputsuffix,'.mat']);
        else
            inputDicefiles{dckk}=dir([inputdir,filesep,'*',diceChanAttbr{dckk},'*',fileFieldSep,outputsuffix,'.mat']);
        end
        numDiceInputFiles(dckk) = numel(inputDicefiles{dckk});
    end
    if ~all(numDiceInputFiles == 0)
        foundDiceFiles = true;
    else
        foundDiceFiles = false;
    end
    
    if ~isempty(sirSensorField)
        inputSirfiles=dir([inputdir,filesep,'*SIR*_',outputsuffix,'.mat']);
    else
        inputSirfiles=dir([inputdir,filesep,'*',fileFieldSep,outputsuffix,'.mat']);
    end
    numSirInputFiles = numel(inputSirfiles);
    if ~isempty(inputSirfiles)
        foundSirFiles = true;
    else
        foundSirFiles = false;
    end
    if ~any([foundDiceFiles foundSirFiles])
        error('genStitchedProds:noFilesToStitch',['Could not find any SIR or DICE picked mat files.\n',...
            'path =%s\nSet pickDice = true for DICE or pickDice = false for SIR'],...
            inputdir)
    elseif all([foundDiceFiles foundSirFiles])
        fprintf('Found both SIR and DICE mat files or cannot determine the sensor type!\n');
        [s,Vok] = listdlg('PromptString','Select a sensor to pick:',...
            'SelectionMode','single',...
            'ListString',{'DICE','SIR'});
        if Vok
            pickDice = (s==1);
        else
            error('genStitchedProds:invalidSelection',['%s, you have to select a sensor to pick!\n',...
                'If you are not sure, flip a coin!'],pickername);
        end
    elseif foundDiceFiles
        pickDice = true;
    else
        pickDice = false;
    end
    clear foundDiceFiles foundSirFiles;
elseif pickDice
    for dckk = diceChans
        if ~isempty(diceSensorField)
            inputDicefiles{dckk}=dir([inputdir,filesep,'*',diceChanAttbr{dckk},'*DICE*_',outputsuffix,'.mat']);
        else
            inputDicefiles{dckk}=dir([inputdir,filesep,'*',diceChanAttbr{dckk},'*',fileFieldSep,outputsuffix,'.mat']);
        end
        numDiceInputFiles(dckk) = numel(inputDicefiles{dckk});
    end
    if all(numDiceInputFiles == 0)
        error('genStitchedProds:noFilesToStitch',['Could not find any DICE picked mat files.\n',...
            'path =%s\nChange the file field identifiers to match the file name structure'],...
            inputdir)
    end
else
    if ~isempty(sirSensorField)
        inputSirfiles=dir([inputdir,filesep,'*SIR*_',outputsuffix,'.mat']);
    else
        inputSirfiles=dir([inputdir,filesep,'*',fileFieldSep,outputsuffix,'.mat']);
    end
    numSirInputFiles = numel(inputSirfiles);
    if isempty(inputSirfiles)
        error('genStitchedProds:noFilesToStitch',['Could not find any SIR picked mat files.\n',...
            'path =%s\nChange the file field identifiers to match the file name structure'],...
            inputdir)
    end
end
%%
if pickDice
    fprintf('Stitching DICE picks...\n')
    %         brushwindow = diceBrushwindow; clear diceBrushwindow;
    %         brightwindow = diceBrightwindow; clear diceBrightwindow;
    %         configFileFilter = diceConfigFileFilter; clear diceConfigFileFilter;
    %         dataFileFilter = diceDataFileFilter; clear diceDataFileFilter;
    %         textdepth = diceTextDepth; clear diceTextDepth;
    %         noisedepth = diceNoiseDepth; clear diceNoiseDepth;
    %         cutoffdepth = diceCutOffDepth; clear diceCutOffDepth;
    SensorField = diceSensorField; clear diceSensorField;
    FileNumField = diceFileNumField; clear diceFileNumField;
    LevelField = diceLevelField; clear diceLevelField;
    outputfiles = inputDicefiles; clear inputDicefiles;
    numOutputFiles = numDiceInputFiles; clear numDiceInputFiles;
    motionCompensated = false;
else
    fprintf('Stitching SIR picks...\n')
    %         brushwindow = sirBrushwindow; clear sirBrushwindow;
    %         brightwindow = sirBrightwindow; clear sirBrightwindow;
    %         configFileFilter = sirConfigFileFilter; clear sirConfigFileFilter;
    %         dataFileFilter = sirDataFileFilter; clear sirDataFileFilter;
    %         textdepth = sirTextDepth; clear sirTextDepth;
    %         noisedepth = sirNoiseDepth; clear sirNoiseDepth;
    %         cutoffdepth = sirCutOffDepth; clear sirCutOffDepth;
    SensorField = sirSensorField; clear sirSensorField;
    FileNumField = sirFileNumField; clear sirFileNumField;
    LevelField = sirLevelField; clear sirLevelField;
    outputfiles{1} = inputSirfiles; clear inputSirfiles;
    numOutputFiles = numSirInputFiles; clear numSirInputFiles;
    diceChans = 1;
end
%%
fprintf('Checking files in dir: %s\n',inputdir);
lastFileLine = [];
if ~all(numOutputFiles ==0)
    for chan = diceChans
        for kk = 1:numOutputFiles(chan)
            [~,filenameOnly,~] = fileparts(outputfiles{chan}(kk).name);
            outfileNameFields{chan} = strsplit(filenameOnly,fileFieldSep);
            outputfiles{chan}(kk).seq = str2double(outfileNameFields{chan}{FileNumField});
            if strncmpi(outfileNameFields{chan}{FlightNumField},'F10',3)
                outputfiles{chan}(kk).Flight = outfileNameFields{chan}{FlightNumField};
                warning('off','MATLAB:load:variableNotFound');
                clearvars unixTime GPS_time;
                load([inputdir,outputfiles{chan}(kk).name],'unixTime','GPS_time');
                if exist('unixTime','var')
                    fileStartTime = unixTime(1);
                    fileEndTime = unixTime(end);
                    clearvars unixTime;
                else
                    fileStartTime = GPS_time(1);
                    fileEndTime = GPS_time(end);
                    clearvars GPS_time;
                end
                warning('on','MATLAB:load:variableNotFound');
                gotLine = find(fileEndTime >= LineTime(:,1) & fileStartTime <=LineTime(:,2));
                if numel(find(gotLine)) == 1
                    outputfiles{chan}(kk).Line = LineNum{gotLine};
                    lastFileLine = [];
                else
                    if numel(find(gotLine)) == 0
                        fprintf('Line # could not be determined for file %s\n',outputfiles{chan}(kk).name);
                    else
                        lineNums = find(gotLine);
                        warning('stitchAllPicks:conflictingLineNumbers','File identified as belonging to more than one line');
                        for gll = numel(lineNums)
                            fprintf('%d. %s\n',gll,LineNum{lineNums(gll)})
                        end
                    end
                    resp = 'n';
                    while (strcmp(resp,'n'))
                        try
                            if ~isempty(lastFileLine)
                                fprintf('(Type in the line number (Hit Enter use %s):',lastFileLine);
                                outputfiles{chan}(kk).Line = input('');
                                if isempty(outputfiles{chan}(kk).Line)
                                    outputfiles{chan}(kk).Line = lastFileLine;
                                    resp = 'y';
                                else
                                    if ~ismember(outputfiles{chan}(kk).Line,LineNum)
                                        fprintf('%s does not exist in the list of Lines in %s\n',outputfiles{chan}(kk).Line,lineFile);
                                    end
                                    resp = input('Is this line number correct (y/n)?:','s');
                                end
                            else
                                outputfiles{chan}(kk).Line = input('Type in the line number (e.g. ''L650'' including (''):');
                                fprintf('You entered %s\n',outputfiles{chan}(kk).Line);
                                if ~ismember(outputfiles{chan}(kk).Line,LineNum)
                                    fprintf('%s does not exist in the list of Lines in %s\n',outputfiles{chan}(kk).Line,lineFile);
                                end
                                resp = input('Is this line number correct (y/n)?:','s');
                            end
                        catch errMsg
                            fprintf('\n%s\n',errMsg.message);
                            resp = 'n';
                        end
                    end
                    lastFileLine = outputfiles{chan}(kk).Line;
                end
            else
                outputfiles{chan}(kk).Line = outfileNameFields{chan}{FlightNumField};
                outputfiles{chan}(kk).Flight = num2str(deploymentNum*1000+FlightNum(ismember(LineNum,outputfiles{chan}(kk).Line)),'F%4d');
            end
        end
        if ~isempty(outputfiles{chan})
            [~,sx] = sort([outputfiles{chan}.seq]);
            outputfiles{chan} = outputfiles{chan}(sx);
        end
    end
else
    error('I cannot find the output files!')
end


for chan = diceChans
    if(numOutputFiles(chan)==0)
        continue;
    end
    Bright_line=zeros(1,1e6);
    MultipleBright_line=zeros(1,1e6);
    NoiseFloor_line=zeros(1,1e6);
    Depth_line=zeros(1,1e6);
    PickTime_line=zeros(1,1e6);
    Lat_line=zeros(1,1e6);
    Lon_line=zeros(1,1e6);
    FlightElev_line=zeros(1,1e6);
    X_line=zeros(1,1e6);
    Y_line=zeros(1,1e6);
    unixTime_line=zeros(1,1e6);
    Surf_Elev_line=zeros(1,1e6);
    SurfTime_line=zeros(1,1e6);
    FlightLineInds_line = zeros(1,1e6);
    startind=1;
    if startfile(chan) == 0
        startfile(chan) = outputfiles{chan}(1).seq;
    end
    if isinf(endfile(chan))
        endfile(chan) = outputfiles{chan}(end).seq;
    end
    for ii=1:numOutputFiles(chan)
        thisfile = outputfiles{chan}(ii).seq;
        if thisfile < startfile(chan)
            continue;
        end
        if thisfile > endfile(chan)
            break;
        end
        
        fprintf('Combining Vectors, file %d\n',thisfile);
        clearvars('Bright','Depth','MultipleBright','NoiseFloor','Lat','Lon','X','Y',...
            'Distance','unixTime','GPS_time','Time','PickTime','Surf_Elev','SurfTime','FlightElev','userRefAlt',...
            'NOTE_VertScale','Notes','motionComp','pickedOnTime','pickerVersion','pickername')
        load([inputdir,outputfiles{chan}(ii).name],'Bright','Depth','MultipleBright','NoiseFloor','Lat','Lon','X','Y',...
            'Distance','unixTime','GPS_time','Time','PickTime','Surf_Elev','SurfTime','FlightElev','userRefAlt',...
            'NOTE_VertScale','Notes','motionComp','pickedOnTime','pickerVersion','pickername');
        warning('off','MATLAB:load:variableNotFound');
        if exist('userRefAlt','var')
            referenceElev = userRefAlt;
            clearvars userRefAlt;
        end
        if ~exist('unixTime','var')
            unixTime = GPS_time;
            clearvars GPS_time;
        end
        if ~exist('motionComp','var')
            motionComp = motionCompensated;
        end
        
        
        Notes.File = outputfiles{chan}(ii).name;
        if ~exist('pickedOnTime','var')
            pickedOnTime = NaN;
        end
        if ~exist('pickerVersion','var')
            pickerVersion = NaN;
        end
        if ~exist('pickername','var')
            pickerVersion = NaN;
        end
        
        Notes.pickedOnTime = pickedOnTime;
        Notes.pickerVersion = pickerVersion;
        Notes.pickername = pickername;
        Notes.VertScale = NOTE_VertScale;
        Notes.Flight = outputfiles{chan}(ii).Flight;
        Notes.Line = outputfiles{chan}(ii).Line;

        
        tempNotes(thisfile-startfile + 1) = Notes;  %#ok<AGROW>
        clearvars Notes;
        
        dx=mean(diff(Distance))*1000;
        samp_int=mean(diff(Time));
        xwavelength_ind=xwavelength/dx;
        
        maxgpstime=max(unixTime_line);
        mingpstime=min(unixTime);
        if mingpstime<maxgpstime
            Bright_overlap=interp1(unixTime,Bright,unixTime_line(unixTime_line>=mingpstime),'linear');
            Bright_line(unixTime_line>=mingpstime)=mean([Bright_line(unixTime_line>=mingpstime);Bright_overlap],1);
            MultipleBright_overlap=interp1(unixTime,MultipleBright,unixTime_line(unixTime_line>=mingpstime),'linear');
            MultipleBright_line(unixTime_line>=mingpstime)=mean([MultipleBright_line(unixTime_line>=mingpstime);MultipleBright_overlap],1);
            NoiseFloor_overlap=interp1(unixTime,NoiseFloor,unixTime_line(unixTime_line>=mingpstime),'linear');
            NoiseFloor_line(unixTime_line>=mingpstime)=mean([NoiseFloor_line(unixTime_line>=mingpstime);NoiseFloor_overlap],1);
            Depth_overlap=interp1(unixTime,Depth,unixTime_line(unixTime_line>=mingpstime),'linear');
            Depth_line(unixTime_line>=mingpstime)=mean([Depth_line(unixTime_line>=mingpstime);Depth_overlap],1);
            Surf_overlap=interp1(unixTime,Surf_Elev,unixTime_line(unixTime_line>=mingpstime),'linear'); %added 2/25/2016
            Surf_Elev_line(unixTime_line>=mingpstime)=mean([Surf_Elev_line(unixTime_line>=mingpstime);Surf_overlap],1); %added 2/25/2016
            PickTime_overlap=interp1(unixTime,PickTime,unixTime_line(unixTime_line>=mingpstime),'linear');
            PickTime_line(unixTime_line>=mingpstime)=mean([PickTime_line(unixTime_line>=mingpstime);PickTime_overlap],1);
            SurfTime_overlap=interp1(unixTime,SurfTime,unixTime_line(unixTime_line>=mingpstime),'linear');
            SurfTime_line(unixTime_line>=mingpstime)=mean([SurfTime(unixTime_line>=mingpstime);SurfTime_overlap],1);
        end
        numnewtraces=length(unixTime(unixTime>maxgpstime));
        stopind=startind+numnewtraces-1;
        Bright_line(startind:stopind)=Bright(unixTime>maxgpstime);
        MultipleBright_line(startind:stopind)=MultipleBright(unixTime>maxgpstime);
        NoiseFloor_line(startind:stopind)=NoiseFloor(unixTime>maxgpstime);
        Depth_line(startind:stopind)=Depth(unixTime>maxgpstime);
        PickTime_line(startind:stopind)=PickTime(unixTime>maxgpstime);
        SurfTime_line(startind:stopind)=SurfTime(unixTime>maxgpstime);
        Lat_line(startind:stopind)=Lat(unixTime>maxgpstime);
        Lon_line(startind:stopind)=Lon(unixTime>maxgpstime);
        FlightElev_line(startind:stopind)=FlightElev(unixTime>maxgpstime);
        X_line(startind:stopind)=X(unixTime>maxgpstime);
        Y_line(startind:stopind)=Y(unixTime>maxgpstime);
        unixTime_line(startind:stopind)=unixTime(unixTime>maxgpstime);
        Surf_Elev_line(startind:stopind)=Surf_Elev(unixTime>maxgpstime); %added 2/25/2016
        FlightLineInds_line(startind:stopind) = ii;   % Line #s are strings so this is just saving the index number of outfile that has the line #
        startind=stopind+1;
    end
    Bright=Bright_line(1:stopind);
    MultipleBright=MultipleBright_line(1:stopind);
    NoiseFloor=NoiseFloor_line(1:stopind);
    Depth=Depth_line(1:stopind);
    PickTime=PickTime_line(1:stopind);
    SurfTime = SurfTime_line(1:stopind);
    Lat=Lat_line(1:stopind);
    Lon=Lon_line(1:stopind);
    FlightElev=FlightElev_line(1:stopind);
    X=X_line(1:stopind); %#ok<NASGU>
    Y=Y_line(1:stopind); %#ok<NASGU>
    unixTime=unixTime_line(1:stopind);
    Surf_Elev=Surf_Elev_line(1:stopind); %added 2/25/2016
    FlightLineInds = FlightLineInds_line(1:stopind);
    donefiltering=0;
    startind=find(isnan(Depth)==0,1,'first');
    if isempty(startind)==0
        while donefiltering==0
            stopind=startind-1+find(isnan(Depth(startind+1:end))==1,1,'first');
            if isempty(stopind)==1
                stopind=length(Depth);
            end
            Depth(startind:stopind)=intuitive_lowpass(Depth(startind:stopind),xwavelength_ind);
            Bright(startind:stopind)=intuitive_lowpass(Bright(startind:stopind),xwavelength_ind);
            MultipleBright(startind:stopind)=intuitive_lowpass(MultipleBright(startind:stopind),xwavelength_ind);
            NoiseFloor(startind:stopind)=intuitive_lowpass(NoiseFloor(startind:stopind),xwavelength_ind);
            PickTime(startind:stopind)=samp_int*round(intuitive_lowpass(PickTime(startind:stopind),xwavelength_ind)/samp_int);
            SurfTime(startind:stopind)=samp_int*round(intuitive_lowpass(SurfTime(startind:stopind),xwavelength_ind)/samp_int);
            Surf_Elev(startind:stopind)=intuitive_lowpass(Surf_Elev(startind:stopind),xwavelength_ind); %added 2/25/2016
            if stopind~=length(Depth)
                startind=stopind+find(isnan(Depth(stopind+1:end))==0,1,'first');
                if isempty(startind)==1
                    donefiltering=1;
                end
            else
                donefiltering=1;
            end
        end
    end
    
    
    Notes = tempNotes; %#ok<NASGU>   
    
    if ~isempty(LevelField)
        outfileLevel = outfileNameFields{chan}{LevelField};
    else
        if ~exist('enteredLevel','var')
            sucessfulEntry = false;
            while(~sucessfulEntry)
                try
                    enteredLevel = input('Enter the product level including ('') e.g. ''level1a''(sir/compressed) ''level2a''(sar) :') ;
                    outfileLevel = enteredLevel;
                catch errMsg
                    fprintf('%s\n',errMsg.message);
                end
                sucessfulEntry = true;
            end
        end
    end
    if ~isempty(SensorField)
        outfileSensor = outfileNameFields{chan}{SensorField};
    else
        if pickDice
            outfileSensor = 'DICE';
        else
            outfileSensor = 'SIR';
        end
    end
    if ~isnan(all(unixTime))
        dateTimeString = datestr(unix2matlabtime(unixTime(find(~isnan(unixTime),1,'first'))),...
            [outFileDateFormat,fileFieldSep,outFileTimeFormat]);
    else
        dateTimeString = [outfileNameFields{chan}(dateField),fileFieldSep,outfileNameFields{chan}(timeField)];
    end
    
    matpath = [outputdir,'mat',filesep];
    if ~exist(matpath,'dir')
        mkdir(matpath)
    end
    outMatFile = [matpath,outfileNameFields{chan}{CampaignField},fileFieldSep,outfileNameFields{chan}{FlightNumField},fileFieldSep,dateTimeString,fileFieldSep,outfileNameFields{chan}{chanField},fileFieldSep,outfileLevel,fileFieldSep,outfileSensor,...
        fileFieldSep,num2str(startfile(chan)),fileFieldSep,num2str(endfile(chan)),fileFieldSep,stitchedSuffix,'.mat'];
    if exist(outMatFile,'file')
        warning('genStitchedProds:outputFileExists','An output file with name %s already exists!\nA new file will be saved with current time suffix',outMatFile)
        [~,outMatFile,~] = fileparts(outMatFile);
        outMatFile = [matpath,outMatFile,datestr(now,'_yyyymmdd_hhMMss'),'.mat'];
    end
    
    % Rename variables for saving
    if motionCompensated
        HorizonElev = referenceElev - SurfTime*c_air/2 - PickTime*c_ice/2;
    else
        HorizonElev = FlightElev - SurfTime*c_air/2 - PickTime*c_ice/2;
        referenceElev = NaN;
    end
    
    HorizonDepthTime = PickTime;
    HorizonDepth = HorizonDepthTime*c_ice/2;
    SurfRange = SurfTime*c_air/2;
    SurfElev = Surf_Elev;
    
    
    save(outMatFile,'Notes','unixTime','Bright','MultipleBright','NoiseFloor','HorizonElev','HorizonDepthTime',...
        'SurfTime','SurfRange','Lat','Lon','FlightElev','X','Y','SurfElev','referenceElev',...
        'motionComp')
    fprintf('Stitched mat file saved as %s.\n',outMatFile);
    
    [~,outfileName,~] = fileparts(outMatFile);
    
    % Create ascii output:
    
    txtpath = [outputdir,filesep,'txt',filesep];
    if ~exist(txtpath,'dir')
        mkdir(txtpath);
    end
    asciiOutFile = [txtpath,outfileName,'.txt'];
    
    unixTime(isnan(unixTime)) = -9999;
    Lat(isnan(Lat)) = -9999;
    Lon(isnan(Lon)) = -9999;
    FlightElev(isnan(FlightElev)) = -9999;
    referenceElev(isnan(referenceElev)) = -9999;
    SurfElev(isnan(SurfElev)) = -9999;
    HorizonElev(isnan(HorizonElev)) = -9999;
    
    fidtxt = fopen(asciiOutFile,'w');
    txtfcleaner = onCleanup(@()fclose(fidtxt));
    
    for llp = 1:numel(unixTime)
        fprintf(fidtxt,'%0.4f,%0.8f,%0.8f,%0.3f,%0.3f,%0.3f,%0.3f,%s,%s\r\n',...
            unixTime(llp),Lat(llp),Lon(llp),FlightElev(llp),referenceElev,...
            SurfElev(llp),HorizonElev(llp),outputfiles{chan}(FlightLineInds(llp)).Flight,outputfiles{chan}(FlightLineInds(llp)).Line);
    end
    clear txtfcleaner;
    
    fprintf('Stitched ascii file saved as %s.\n',asciiOutFile);
end

% create a txt file with header info for the ascii data
if ~exist([txtpath,'headers.txt'],'file')
    fidh = fopen([txtpath,'headers.txt'],'w');
    hfcleaner = onCleanup(@()fclose(fidh));
    fprintf(fidh,'UnixTime,Lat,Lon,FlightElev,RefElev,SurfElev,HorizonElev,Flight,Line\r\n');
    fprintf(fidh,'s,deg,deg,m,m,m,m,,\r\n\r\n');
    fprintf(fidh,'Description of variables:\r\n');
    fprintf(fidh,['    UnixTime: unix seconds (slow-''along track'' time) of each echo, these are number of seconds since 1970 adjusted for leap seconds\r\n',...
        '    Lat: Latitude of echo in degrees\r\n',...
        '    Lon: Longitude of echo in degrees\r\n',...
        '    FlightElev: Ellipsoidal height of the aircraft in meters\r\n',...
        '    RefElev: If valid, this is the ellipsoidal height of radar in meters after motion correction\r\n',...
        '    SurfElev: Ellipsoidal height of the surface closest to the radar in meters\r\n',...
        '    HorizonElev: Ellipsoidal height of the picked horizon (layer) in meters\r\n',...
        '    Flight: Flight number in ''FD###'' format, D = deployment number ### = flight number for the deployment\r\n',...
        '    Line: Line number, typically in L# or T# format, L for E/W lines T for N/S (Tie) Lines\r\n',...
        '    Lines that do not conform to a grid have different naming convention - see Data Systems Standard and Conventions in doc-repo\r\n',...
        'Invalid values are set to -9999\r\n\r\n',...
        'For data related questions and comments contact Tej Dhakal (dhakal@ldeo.columbia.edu)\r\n']);
    
    % unixTime: Number of seconds since 1970 adjusted for leap seconds (not true unix time)
    % Bright: signal power (dB) of the pixel. This is a relative number with 0 dB being some
    %       arbitrary value that is consistent across the campaign
    % MultipleBright: signal power (dB) of the multiple of the picked layer
    % NoiseFloor: signal power (dB) of spot in the image that does not contain returns or artifacts.
    % xdisp: x-axis of the display image
    % VertScale: y/range scale with surface set to zero at the surface +ve above and -ve below
    % X: easting km in SCAR projection
    % Y: northing km in SCAR projection
    % Lat: Latitude of echo in degrees
    % Lon: Longitude of echo in degree
    % FlightElev: Ellipsoid flight elevation in m. If motion compensation is
    %               ture, FlightElev is irrelevant
    % Distance: along-track distance in km for the image
    % Notes: structure contianing picked areas and other stuff
    %   .pickType: information on what is being picked: bet, layer etc.
    %   .platform: sensor platform. icepod, oibp3 etc..
    %   .Proj_Campaign: project/campaign the data belongs to
    %   .Flight_Line: flight or line number the data belongs to
    %   .Sensor: name of the sensor, SIR for example.
    %   .SourceProdLevel: product level of the source file, compressed, sar etc.
    %   .Sensor: name of the sensor, SIR for example.
    %   .VertScale: speficies how VertScale variable is defined
    %   .pickedOnTime: matlab datetime for when the pick was done
    %   .pickerVersion: version number of the picking script used
    % SurfElev: this is ellipsoid elevation of the surface
    % referenceElev: elevation correciton is performed to this altitude, if motion
    %               compensation is true, this is the flight elevation.
    % motionComp: if true(1), image was compensated for aircraft motion
    
    clear hfcleaner;
    fprintf('Headers txt file saved as ''headers.txt''\n');
end
warning('on','MATLAB:load:variableNotFound');
end